/*
/////////////
/// GetDP ///
/////////////

// File: definitionOfMagnetostaticProblem.pro
// AUTHOR: Frederic Trillaud <ftrillaudp@gmail.com>
// UNIVERSITY: UNAM
// INSTITUTE: IINGEN
// DATE (english): 10/31/2012, 02/20/2013
// UNITS: SI otherwise indicated

// INTRODUCTION: 2D magnetostatic model of a brushless motor. The resolution is performed based on a 2D magnetstatic potential vector method.

// Computation: getdp definitionOfMagnetostaticProblem -msh ../../GmshFiles/MshFiles/motor.msh -solve potentialVectorResolution -pos fieldMap
*/


///////////////////////////
/// EXTERNAL PARAMETERS ///
///////////////////////////

Include "./permanentMagnet.par";


///////////////
/// REGIONS ///
///////////////

Group
{
// Name of regions:
rotorRegion = Region[rotorID];
statorRegion = Region[statorID];
airGapRegion = Region[airGapID];
For i In {0:1}
 Printf("Value of index, PMID: %g", PMID);
 PMRegion~{i+1} = Region[PMID];
 PMID = PMID+1;
EndFor
infiniteBoundaryRegion = Region[infiniteBoundarySpaceID];
boundaryLineRegion = Region[boundaryLineID];

// Domains:
ferromagneticDomain = Region[{statorRegion}];
infiniteBoundaryDomain = Region[{infiniteBoundaryRegion}];
paramagneticDomain = Region[{rotorRegion, airGapRegion, infiniteBoundaryDomain}];
permanentMagnetDomain = Region[{PMRegion_1, PMRegion_2}];
magneticSolutionDomain = Region[{ferromagneticDomain, paramagneticDomain, permanentMagnetDomain}];
boundaryLineDomain = Region[{boundaryLineRegion}];
}

Function
{
// Permeability of vacuum:
muVacuum = 4*Pi*1e-7;
nu[Region[{paramagneticDomain, permanentMagnetDomain}]] = 1./muVacuum;
// Permeability of core: 
muFerromagnetic = 1.*muVacuum;
nu[ferromagneticDomain] = 1./muFerromagnetic;
// Coercivity of permanent magnet:
hc[PMRegion_1] = Vector[881300., 0., 0.];
hc[PMRegion_2] = Vector[-881300., 0., 0.];
}

Constraint
{
 {
  Name dirichletBoundaryCondition;
  Type Assign;
  Case
  {
   {
    Region boundaryLineDomain;
    Value 0.;
   }
  }
 }
}


///////////////
/// METHODS ///
///////////////

// Including external files defining the models to be used
Include "./jacobianMethod.pro";
Include "./integrationMethod.pro";
Include "./methodForMagnetostaticProblem.pro";


//////////////////////
/// POSTPROCESSING ///
//////////////////////

PostOperation
{
 {
  Name fieldMap; // to be called: getdp definitionOfMagnetostaticProblem -msh ../../GmhsFiles/MshFiles/motor.msh -pos fieldMap
  NameOfPostProcessing postProcessing;
  Operation
  {
   Print[A, OnElementsOf magneticSolutionDomain, File "./potentialVector.pos"];
   Print[Amod, OnElementsOf magneticSolutionDomain, File "./moduleOfMagneticPotentialVector.pos"];
   Print[B, OnElementsOf magneticSolutionDomain, File "./magneticFluxDensity.pos"];
   Print[Bmod, OnElementsOf magneticSolutionDomain, File "./moduleOfMagneticFluxDensity.pos"];
//   Print[Bmod, OnPoint {distance_axe_symmetry_inductor, 0., 0.}, Format Table, File "../ResFiles/maximumMagneticFluxDensity.dat"];
   Print[H, OnElementsOf magneticSolutionDomain, File "./magneticField.pos"];
   Print[Hmod, OnElementsOf magneticSolutionDomain, File "./moduleOfMagneticField.pos"];
   Print[Hpm, OnElementsOf permanentMagnetDomain, File "./magneticFieldOfPermanentMagnets.pos"];
//   Print[J, OnElementsOf magneticSolutionDomain, File "../ResFiles/currentDensity.pos"];
//   Print[Jmod, OnElementsOf magneticSolutionDomain, File "../ResFiles/moduleOfCurrentDensity.pos"];
   Print[Emag[magneticSolutionDomain], OnGlobal, Format Table, File "./magneticEnergy.dat"];
  }
 }
}


