/*
/////////////
/// GetDP ///
/////////////

// File: methodForMagnetostaticProblem.pro
// AUTHOR: Frederic Trillaud <ftrillaudp@gmail.com>
// UNIVERSITY: UNAM
// INSTITUTE: IINGEN
// DATE (english): 01/10/2013, 02/20/2013
// UNITS: SI otherwise indicated

// INTRODUCTION: Model to be sused for resolution.

Inputs:
-------

GlobalGroup:
magneticSolutionDomain -> Whole magnetic domain to be resolved
inductorDomain -> Conductor regions
permanentMagnetDomain -> regions corresponding to permanent magnets

Function:
nu[] -> magnetic reluctivity
hc[] -> coercitive magnetic field

Constraint:
dirichletBoundaryCondition -> Fixed magnetic vector potential (classical boundary conditions in 2D)
currentDensity -> Fixed current density corresponding to the source (depends on direction)
*/


///////////////
/// REGIONS ///
///////////////

Group
{
 DefineGroup[magneticSolutionDomain, permanentMagnetDomain];
}

Function
{
 DefineFunction[nu, hc];
}


//////////////////////
/// FUNCTION SPACE ///
//////////////////////

FunctionSpace
{
 { // Potential vector
  Name potential_function_space;
  Type Form1P;
  BasisFunction
  {
   {
    Name phi_node;
    NameOfCoef a_node;
    Function BF_PerpendicularEdge;
    Support magneticSolutionDomain;
    Entity NodesOf[All];
   }
  }
  Constraint
  {
   {
    NameOfCoef a_node;
    EntityType NodesOf;
    NameOfConstraint dirichletBoundaryCondition;
   }
  }
 }
}


///////////////////
/// FORMULATION ///
///////////////////

Formulation
{
 {
  Name potentialVectorFormulation;
  Type FemEquation;
  Quantity
  {
   {
    Name A;
    Type Local;
    NameOfSpace potential_function_space;
   }
  }
  Equation
  {
   Galerkin // magnetic solution domain (entire domain)
   { 
    [nu[]*Dof{d A}, {d A}]; // d in 2D and Curl in 3D 
    In magneticSolutionDomain;
    Jacobian jacobianVolumeRegion;
    Integration basicIntegration;
   }
   Galerkin // Permanent magnet PM1
   {
    [hc[], {d A}];
    In permanentMagnetDomain;
    Jacobian jacobianVolumeRegion;
    Integration basicIntegration;
   }
  }
 }
}


//////////////////
/// RESOLUTION ///
//////////////////

Resolution
{
 {
  Name potentialVectorResolution; // to be called: getdp definitionOfMagnetostaticProblem -msh ../../GmshFiles/MshFiles/motor.msh -solve potentialVectorResolution
  System
  {
   { 
    Name potentialVector;
    NameOfFormulation potentialVectorFormulation;
   }
  }
  Operation
  {
  // InitSolution[potentialVector];
   Generate[potentialVector];
   Solve[potentialVector];
   SaveSolution[potentialVector];
  }
 }
}


//////////////////////
/// POSTPROCESSING ///
//////////////////////

PostProcessing
{
 {
  Name postProcessing;
  NameOfFormulation potentialVectorFormulation;
  Quantity
  {
   {Name A; Value{Local{[{A}]; In magneticSolutionDomain; Jacobian jacobianVolumeRegion;}}}
   {Name Amod; Value{Local{[Norm[{A}]]; In magneticSolutionDomain; Jacobian jacobianVolumeRegion;}}}
   {Name H; Value{Local{[nu[]*{d A}]; In magneticSolutionDomain; Jacobian jacobianVolumeRegion;} 
                  Local{[hc[]]; In PMRegion_1; Jacobian jacobianVolumeRegion;}
                  Local{[hc[]]; In PMRegion_2; Jacobian jacobianVolumeRegion;}
                 }
   }
   {Name Hpm; Value{Local{[hc[]]; In PMRegion_1; Jacobian jacobianVolumeRegion;}
                    Local{[hc[]]; In PMRegion_2; Jacobian jacobianVolumeRegion;}
                   }
   }
   {Name Hmod; Value{Local{[Norm[nu[]*{d A}]]; In magneticSolutionDomain; Jacobian jacobianVolumeRegion;}}}
   {Name B; Value{Local{[{d A}]; In magneticSolutionDomain; Jacobian jacobianVolumeRegion;}}}
   {Name Bmod; Value{Local{[Norm[{d A}]]; In magneticSolutionDomain; Jacobian jacobianVolumeRegion;}}}
//   {Name J; Value{Local{[{Je}] ; In inductorDomain; Jacobian jacobianVolumeRegion;}}}
//   {Name Jmod; Value{Local{[Norm[{Je}]]; In inductorDomain; Jacobian jacobianVolumeRegion;}}}
   {Name Emag; Value{Integral {[SquNorm[{d A}]*nu[]*2.*Pi/2.]; In magneticSolutionDomain; Jacobian jacobianVolumeRegion; Integration basicIntegration;}}}
  }
 }
}


